
import nz.ac.waikato.modeljunit.GreedyTester;
import nz.ac.waikato.modeljunit.RandomTester;
import nz.ac.waikato.modeljunit.VerboseListener;
import nz.ac.waikato.modeljunit.coverage.CoverageMetric;
import nz.ac.waikato.modeljunit.coverage.StateCoverage;
import nz.ac.waikato.modeljunit.coverage.TransitionCoverage;

//ONLINE testing: la generazione degli input  contemporanea con la loro applicazione alla macchina FSM testata
public class TestOnline {

	public static void main(String args[]) {
		//Creo un'istanza di onOff e lo uso come modello
		SensoriFSM model = new SensoriFSM();
        
        //Creo un tester di tipo GreedyTester e gli passo model
        GreedyTester testerGreedy = new GreedyTester(model);
        //Setto la probabilit di reset all'1 % di probabilit
        testerGreedy.setResetProbability(0.01);
				
		//Creo un tester di tipo RandomTester e gli passo model
        RandomTester testerRandom = new RandomTester(model);
      //Setto la probabilit di reset all'1 % di probabilit
        testerRandom.setResetProbability(0.01);

		//Costruisco il grafo FSM completo per il nostro modello per poter essere sicuri di avere metriche di copertura accurate
		testerGreedy.buildGraph();
		testerRandom.buildGraph();

		//Copertura degli stati
	    CoverageMetric stateCoverageGreedy = new StateCoverage();
	    testerGreedy.addCoverageMetric(stateCoverageGreedy);
	    CoverageMetric stateCoverageRandom = new StateCoverage();
	    testerRandom.addCoverageMetric(stateCoverageRandom);
	    
	    //Copertura delle transisiozni
	    CoverageMetric transitionCoverageGreedy = new TransitionCoverage();
	    testerGreedy.addCoverageMetric(transitionCoverageGreedy);
	    CoverageMetric transitionCoverageRandom = new TransitionCoverage();
	    testerRandom.addCoverageMetric(transitionCoverageRandom);
		    
	    //Richiesta per poter visualizzare i test generati
	    testerGreedy.addListener(new VerboseListener());
	    testerRandom.addListener(new VerboseListener());

	    //Genera un'insieme di casi di test composto da 1000 casi di test
	    testerGreedy.generate(1000);
	    testerRandom.generate(1000);

	    //Visualizzo copertura degli stati del modello usando GreedyTester
	    System.out.println("Copertura degli stati con GreedyTester = "+stateCoverageGreedy.toString());

	    //Visualizzo copertura delle transizioni del modello usando GreedyTester
	    System.out.println("Copertura delle transizioni con GreedyTester = "+transitionCoverageGreedy.toString());
	
	    //Visualizzo copertura degli stati del modello usando RandomTester
	    System.out.println("Copertura degli stati con RandomTester = "+stateCoverageRandom.toString());
	  
	    //Visualizzo copertura delle transizioni del modello usando RandomTester
	    System.out.println("Copertura delle transizioni con RandomTester = "+transitionCoverageRandom.toString());
		
	}
}